# Datasets
Links to some datasets generated as part of the PLANC project.
* Pixel similarity matrices used in SymNMF experiments. [[doi]](https://doi.org/10.5281/zenodo.3877635)
* Aminer-MAG dataset used in JointNMF experiments. [[doi]](https://doi.org/10.5281/zenodo.7893403), [[doi]](https://doi.org/10.5281/zenodo.7938102)